@@ -81,6 +81,23 @@ _EXTRA_COLORS = {
 
 _mpl.colors.EXTRA_COLORS = _EXTRA_COLORS
 _mpl.colors.colorConverter.colors.update(_EXTRA_COLORS)
+_mpl.cm.register_cmap(
+    name="bird",
+    cmap=_mpl.colors.LinearSegmentedColormap.from_list(
+        "bird",
+        [
+            (0.0592, 0.3599, 0.8684),
+            (0.078, 0.5041, 0.8385),
+            (0.0232, 0.6419, 0.7914),
+            (0.1802, 0.7178, 0.6425),
+            (0.5301, 0.7492, 0.4662),
+            (0.8186, 0.7328, 0.3499),
+            (0.9956, 0.7862, 0.1968),
+            (0.9764, 0.9832, 0.0539),
+        ],
+        N=2560,
+    ),
+)
 
 
 def set_color_cycle(pal=None, n=4):
